@@ -393,11 +393,10 @@ class SpotifyPrivate(SpotifyCredential):
         """
         decompressed_response = gzip.decompress(request.content)
         my_json = decompressed_response.decode('utf-8')
-        # my_json = f'[{my_json}]'
-        # my_json = my_json.replace('\n', '')
-        # my_json = my_json.replace('}{', '},{')
-        # return json.loads(my_json)
-        return my_json
+        my_json = f'[{my_json}]'
+        my_json = my_json.replace('\n', '')
+        my_json = my_json.replace('}{', '},{')
+        return json.loads(my_json)
 
     def get_tracks(self) -> pd.DataFrame:
         """
